<?php
/*
Plugin Name: AMP Plugin Filter
Plugin URI: https://tehnoblog.org/how-to-fix-google-search-console-amp-image-size-smaller-than-recommended-in-wordpress/
Description: Simple plugin to replace small or missing featured images in AMP plugin and avoid Google Search Console AMP pages warnings
Author: TehnoBlog.org
Author URI: https://tehnoblog.org/
Version: 0.0.1
*/

if ( !defined('ABSPATH') ) {
    exit;
}

// amp pages: metadata filter
function amp_plugin_modify_json_metadata($metadata, $post) {
	if ('post'=== $post->post_type) {
		// set custom article image
		// if original is missing / not found
		// or if featured image width or height dimension is smaller than 1200 pixels
		// you must place "amp_preview_image.jpg" in /wp-content/images/ sub-directory
		// also you can change image extension to .png or any other instead of .jpg defined below
		// also UPDATE IMAGE height AND width NUMBERS TO MATCH YOUR GENERIC IMAGE SIZE (in pixels)
		$countArticleImages = isset($metadata['image']) ? count($metadata['image']) : 0;
		if (
			$countArticleImages == 0
			||
			( ($metadata['image']['width'] >= $metadata['image']['height']) && ($metadata['image']['width'] < 1200) )
			||
			( ($metadata['image']['width'] < $metadata['image']['height']) && ($metadata['image']['height'] < 1200) )
		) {
			$metadata['image'] = array(
				'@type'  => 'ImageObject',
				'url'    => WP_CONTENT_URL.'/images/amp_preview_image.jpg',
				'height' => 1200, // <-- UPDATE NUMBER TO MATCH YOUR GENERIC IMAGE SIZE (px)
				'width'  => 1200  // <-- UPDATE NUMBER TO MATCH YOUR GENERIC IMAGE SIZE (px)
			);
		}
	}
	return $metadata; 
}
add_filter('amp_post_template_metadata', 'amp_plugin_modify_json_metadata', 10, 2);
?>